==> comfyui_embedded_docs-0.2.0-py3-none-any.whl: comfyui_embedded_docs/docs/ClipTextEncodeHunyuanDit/es.md <==

Las funciones principales del nodo `CLIPTextEncodeHunyuanDiT` son:

- **Tokenización**: Convierte el texto de entrada en secuencias de tokens que pueden ser procesadas por el modelo.
- **Codificación**: Utiliza el modelo CLIP para codificar secuencias de tokens en codificaciones condicionales.

Este nodo puede verse como un "traductor de lenguaje" que convierte el texto de entrada del usuario (ya sea en inglés u otros idiomas) en "lenguaje máquina" que los modelos de IA pueden entender, permitiendo que el modelo genere contenido correspondiente basado en estas condiciones.


## Tipos de Entrada de CLIP Text Encode Hunyuan DiT

| Parámetro | Tipo de Datos Comfy | Descripción |
| --------- | ------------------ | ----------- |
| `clip`    | `CLIP`             | Una instancia del modelo CLIP para tokenización y codificación de texto, fundamental para generar condiciones. |
| `bert`    | `STRING`           | Entrada de texto para codificación, admite prompts multilínea y dinámicos. |
| `mt5xl`   | `STRING`           | Otra entrada de texto para codificación, admite prompts multilínea y dinámicos (multilingüe). |

- **Parámetro `bert`**: Adecuado para entrada de texto en inglés. Se recomienda ingresar texto conciso con contexto para ayudar al nodo a generar representaciones de tokens más precisas y significativas.
- **Parámetro `mt5xl`**: Adecuado para entrada de texto multilingüe. Puede ingresar texto en cualquier idioma para ayudar al modelo a comprender tareas multilingües.

## Tipos de Salida de CLIP Text Encode Hunyuan DiT

| Parámetro | Tipo de Datos Comfy | Descripción |
| --------- | ------------------ | ----------- |
| `conditioning` | `CONDITIONING` | Salida condicional codificada para procesamiento posterior en tareas de generación. |

## Métodos

- **Método de Codificación**: `encode`
  
  Este método acepta `clip`, `bert` y `mt5xl` como parámetros. Primero, tokeniza `bert`, luego tokeniza `mt5xl`, y almacena los resultados en un diccionario `tokens`. Finalmente, utiliza el método `clip.encode_from_tokens_scheduled` para codificar los tokens en condiciones.


## Contenido Extendido para el Nodo CLIP Text Encode Hunyuan DiT

### BERT (Bidirectional Encoder Representations from Transformers)

BERT es un modelo de representación de lenguaje bidireccional basado en la arquitectura Transformer.

Aprende información contextual rica a través del pre-entrenamiento en grandes cantidades de datos de texto, luego se ajusta para tareas específicas para lograr un alto rendimiento.

**Características Principales:**

- **Bidireccionalidad**: BERT considera la información contextual tanto izquierda como derecha simultáneamente, permitiendo una mejor comprensión del significado de las palabras.

- **Pre-entrenamiento y Ajuste Fino**: A través de tareas de pre-entrenamiento (como Masked Language Model y Next Sentence Prediction), BERT puede ajustarse rápidamente para varias tareas específicas.

**Escenarios de Aplicación:**

- Clasificación de Texto

- Reconocimiento de Entidades Nombradas

- Sistemas de Respuesta a Preguntas

### mT5-XL (Multilingual Text-to-Text Transfer Transformer)

mT5-XL es la versión multilingüe del modelo T5, utilizando una arquitectura codificador-decodificador que admite el procesamiento de múltiples idiomas.

Unifica todas las tareas de NLP como transformaciones texto-a-texto, capaz de manejar varias tareas incluyendo traducción, resumen y respuesta a preguntas.

**Características Principales:**

- **Soporte Multilingüe**: mT5-XL admite el procesamiento de hasta 101 idiomas.

- **Representación Unificada de Tareas**: Convierte todas las tareas en formato texto-a-texto, simplificando el proceso de procesamiento.

**Escenarios de Aplicación:**

- Traducción Automática

- Resumen de Texto

- Sistemas de Respuesta a Preguntas

### Artículos de Investigación sobre BERT y mT5-XL

1. [BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://arxiv.org/pdf/1810.04805)
   - **Descripción**: Este artículo fundamental introduce BERT, un modelo basado en transformers que logra resultados estado del arte en una amplia gama de tareas NLP.
   
2. [mT5: A Massively Multilingual Pre-trained Text-to-Text Transformer](https://aclanthology.org/2021.naacl-main.41.pdf)
   - **Descripción**: Este artículo presenta mT5, una variante multilingüe de T5, entrenada en un nuevo conjunto de datos basado en Common Crawl que cubre 101 idiomas.
   
3. [mLongT5: A Multilingual and Efficient Text-To-Text Transformer for Longer Sequences](https://arxiv.org/pdf/2112.08760)
   - **Descripción**: Este trabajo desarrolla mLongT5, un modelo multilingüe diseñado para manejar secuencias de entrada más largas de manera eficiente.

4. [Bridging Linguistic Barriers: Inside Google's mT5 Multilingual Technology](https://medium.com/@rukaiya.rk24/bridging-linguistic-barriers-inside-googles-mt5-multilingual-technology-4a85e6ca056f)
   - **Descripción**: Un artículo que discute las capacidades y aplicaciones del modelo mT5 de Google en tareas NLP multilingües.

5. [BERT-related Papers](https://github.com/tomohideshibata/BERT-related-papers)
   - **Descripción**: Una lista curada de artículos de investigación relacionados con BERT, incluyendo estudios, tareas específicas y modificaciones.

==> comfyui_embedded_docs-0.2.1-py3-none-any.whl: comfyui_embedded_docs/docs/ClipTextEncodeHunyuanDit/es.md <==

Las funciones principales del nodo `CLIPTextEncodeHunyuanDiT` son:

- **Tokenización**: Convierte el texto de entrada en secuencias de tokens que pueden ser procesadas por el modelo.
- **Codificación**: Utiliza el modelo CLIP para codificar secuencias de tokens en codificaciones condicionales.

Este nodo puede verse como un "traductor de lenguaje" que convierte el texto de entrada del usuario (ya sea en inglés u otros idiomas) en "lenguaje máquina" que los modelos de IA pueden entender, permitiendo que el modelo genere contenido correspondiente basado en estas condiciones.

## Entradas

| Parámetro | Tipo de Datos Comfy | Descripción |
| --------- | ------------------ | ----------- |
| `clip`    | `CLIP`             | Una instancia del modelo CLIP para tokenización y codificación de texto, fundamental para generar condiciones. |
| `bert`    | `STRING`           | Entrada de texto para codificación, admite prompts multilínea y dinámicos. |
| `mt5xl`   | `STRING`           | Otra entrada de texto para codificación, admite prompts multilínea y dinámicos (multilingüe). |

- **Parámetro `bert`**: Adecuado para entrada de texto en inglés. Se recomienda ingresar texto conciso con contexto para ayudar al nodo a generar representaciones de tokens más precisas y significativas.
- **Parámetro `mt5xl`**: Adecuado para entrada de texto multilingüe. Puede ingresar texto en cualquier idioma para ayudar al modelo a comprender tareas multilingües.

## Salidas

| Parámetro | Tipo de Datos Comfy | Descripción |
| --------- | ------------------ | ----------- |
| `CONDITIONING` | CONDITIONING | Salida condicional codificada para procesamiento posterior en tareas de generación. |

## Métodos

- **Método de Codificación**: `encode`
  
  Este método acepta `clip`, `bert` y `mt5xl` como parámetros. Primero, tokeniza `bert`, luego tokeniza `mt5xl`, y almacena los resultados en un diccionario `tokens`. Finalmente, utiliza el método `clip.encode_from_tokens_scheduled` para codificar los tokens en condiciones.

## Contenido Extendido para el Nodo CLIP Text Encode Hunyuan DiT

### BERT (Bidirectional Encoder Representations from Transformers)

BERT es un modelo de representación de lenguaje bidireccional basado en la arquitectura Transformer.

Aprende información contextual rica a través del pre-entrenamiento en grandes cantidades de datos de texto, luego se ajusta para tareas específicas para lograr un alto rendimiento.

**Características Principales:**

- **Bidireccionalidad**: BERT considera la información contextual tanto izquierda como derecha simultáneamente, permitiendo una mejor comprensión del significado de las palabras.

- **Pre-entrenamiento y Ajuste Fino**: A través de tareas de pre-entrenamiento (como Masked Language Model y Next Sentence Prediction), BERT puede ajustarse rápidamente para varias tareas específicas.

**Escenarios de Aplicación:**

- Clasificación de Texto

- Reconocimiento de Entidades Nombradas

- Sistemas de Respuesta a Preguntas

### mT5-XL (Multilingual Text-to-Text Transfer Transformer)

mT5-XL es la versión multilingüe del modelo T5, utilizando una arquitectura codificador-decodificador que admite el procesamiento de múltiples idiomas.

Unifica todas las tareas de NLP como transformaciones texto-a-texto, capaz de manejar varias tareas incluyendo traducción, resumen y respuesta a preguntas.

**Características Principales:**

- **Soporte Multilingüe**: mT5-XL admite el procesamiento de hasta 101 idiomas.

- **Representación Unificada de Tareas**: Convierte todas las tareas en formato texto-a-texto, simplificando el proceso de procesamiento.

**Escenarios de Aplicación:**

- Traducción Automática

- Resumen de Texto

- Sistemas de Respuesta a Preguntas

### Artículos de Investigación sobre BERT y mT5-XL

1. [BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://arxiv.org/pdf/1810.04805)
   - **Descripción**: Este artículo fundamental introduce BERT, un modelo basado en transformers que logra resultados estado del arte en una amplia gama de tareas NLP.

2. [mT5: A Massively Multilingual Pre-trained Text-to-Text Transformer](https://aclanthology.org/2021.naacl-main.41.pdf)
   - **Descripción**: Este artículo presenta mT5, una variante multilingüe de T5, entrenada en un nuevo conjunto de datos basado en Common Crawl que cubre 101 idiomas.

3. [mLongT5: A Multilingual and Efficient Text-To-Text Transformer for Longer Sequences](https://arxiv.org/pdf/2112.08760)
   - **Descripción**: Este trabajo desarrolla mLongT5, un modelo multilingüe diseñado para manejar secuencias de entrada más largas de manera eficiente.

4. [Bridging Linguistic Barriers: Inside Google's mT5 Multilingual Technology](https://medium.com/@rukaiya.rk24/bridging-linguistic-barriers-inside-googles-mt5-multilingual-technology-4a85e6ca056f)
   - **Descripción**: Un artículo que discute las capacidades y aplicaciones del modelo mT5 de Google en tareas NLP multilingües.

5. [BERT-related Papers](https://github.com/tomohideshibata/BERT-related-papers)
   - **Descripción**: Una lista curada de artículos de investigación relacionados con BERT, incluyendo estudios, tareas específicas y modificaciones.
